import { IConnector } from '../../common/connector';
import { ISDL, DatabaseType } from 'prisma-datamodel';
import { DocumentIntrospectionResult } from './documentIntrospectionResult';
import { Data } from './data';
export declare enum SamplingStrategy {
    One = "One",
    All = "All",
    Random = "Random"
}
export interface DataIterator {
    hasNext(): Promise<boolean>;
    next(): Promise<Data>;
}
export declare abstract class DocumentConnector<InternalCollectionType> implements IConnector {
    protected samplingStrategy: any;
    constructor(samplingStrategy: SamplingStrategy);
    abstract getDatabaseType(): DatabaseType;
    abstract listSchemas(): Promise<string[]>;
    protected abstract getInternalCollections(schema: string): Promise<{
        name: string;
        collection: InternalCollectionType;
    }[]>;
    abstract introspect(schema: string): Promise<DocumentIntrospectionResult>;
    protected abstract sampleOne(collection: InternalCollectionType): Promise<DataIterator>;
    protected abstract sampleMany(collection: InternalCollectionType, limit: number): Promise<DataIterator>;
    protected abstract sampleAll(collection: InternalCollectionType): Promise<DataIterator>;
    protected abstract exists(collection: InternalCollectionType, id: any): Promise<boolean>;
    sample(collection: InternalCollectionType): Promise<DataIterator>;
    listModels(schemaName: string): Promise<ISDL>;
}
